==> zio-aws-firehose_2.13-7.28.26.1-sources.jar: zio/aws/firehose/model/ElasticsearchDestinationDescription.scala <==
package zio.aws.firehose.model
import zio.aws.firehose.model.primitives.{
  ElasticsearchIndexName,
  ElasticsearchTypeName,
  ElasticsearchDomainARN,
  RoleARN,
  ElasticsearchClusterEndpoint
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class ElasticsearchDestinationDescription(
    roleARN: Optional[RoleARN] = Optional.Absent,
    domainARN: Optional[ElasticsearchDomainARN] = Optional.Absent,
    clusterEndpoint: Optional[ElasticsearchClusterEndpoint] = Optional.Absent,
    indexName: Optional[ElasticsearchIndexName] = Optional.Absent,
    typeName: Optional[ElasticsearchTypeName] = Optional.Absent,
    indexRotationPeriod: Optional[
      zio.aws.firehose.model.ElasticsearchIndexRotationPeriod
    ] = Optional.Absent,
    bufferingHints: Optional[
      zio.aws.firehose.model.ElasticsearchBufferingHints
    ] = Optional.Absent,
    retryOptions: Optional[zio.aws.firehose.model.ElasticsearchRetryOptions] =
      Optional.Absent,
    s3BackupMode: Optional[zio.aws.firehose.model.ElasticsearchS3BackupMode] =
      Optional.Absent,
    s3DestinationDescription: Optional[
      zio.aws.firehose.model.S3DestinationDescription
    ] = Optional.Absent,
    processingConfiguration: Optional[
      zio.aws.firehose.model.ProcessingConfiguration
    ] = Optional.Absent,
    cloudWatchLoggingOptions: Optional[
      zio.aws.firehose.model.CloudWatchLoggingOptions
    ] = Optional.Absent,
    vpcConfigurationDescription: Optional[
      zio.aws.firehose.model.VpcConfigurationDescription
    ] = Optional.Absent,
    documentIdOptions: Optional[zio.aws.firehose.model.DocumentIdOptions] =
      Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription = {
    import ElasticsearchDestinationDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
      .builder()
      .optionallyWith(
        roleARN.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARN)
      .optionallyWith(
        domainARN.map(value =>
          ElasticsearchDomainARN.unwrap(value): java.lang.String
        )
      )(_.domainARN)
      .optionallyWith(
        clusterEndpoint.map(value =>
          ElasticsearchClusterEndpoint.unwrap(value): java.lang.String
        )
      )(_.clusterEndpoint)
      .optionallyWith(
        indexName.map(value =>
          ElasticsearchIndexName.unwrap(value): java.lang.String
        )
      )(_.indexName)
      .optionallyWith(
        typeName.map(value =>
          ElasticsearchTypeName.unwrap(value): java.lang.String
        )
      )(_.typeName)
      .optionallyWith(indexRotationPeriod.map(value => value.unwrap))(
        _.indexRotationPeriod
      )
      .optionallyWith(bufferingHints.map(value => value.buildAwsValue()))(
        _.bufferingHints
      )
      .optionallyWith(retryOptions.map(value => value.buildAwsValue()))(
        _.retryOptions
      )
      .optionallyWith(s3BackupMode.map(value => value.unwrap))(_.s3BackupMode)
      .optionallyWith(
        s3DestinationDescription.map(value => value.buildAwsValue())
      )(_.s3DestinationDescription)
      .optionallyWith(
        processingConfiguration.map(value => value.buildAwsValue())
      )(_.processingConfiguration)
      .optionallyWith(
        cloudWatchLoggingOptions.map(value => value.buildAwsValue())
      )(_.cloudWatchLoggingOptions)
      .optionallyWith(
        vpcConfigurationDescription.map(value => value.buildAwsValue())
      )(_.vpcConfigurationDescription)
      .optionallyWith(documentIdOptions.map(value => value.buildAwsValue()))(
        _.documentIdOptions
      )
      .build()
  }
  def asReadOnly
      : zio.aws.firehose.model.ElasticsearchDestinationDescription.ReadOnly =
    zio.aws.firehose.model.ElasticsearchDestinationDescription
      .wrap(buildAwsValue())
}
object ElasticsearchDestinationDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.ElasticsearchDestinationDescription =
      zio.aws.firehose.model.ElasticsearchDestinationDescription(
        roleARN.map(value => value),
        domainARN.map(value => value),
        clusterEndpoint.map(value => value),
        indexName.map(value => value),
        typeName.map(value => value),
        indexRotationPeriod.map(value => value),
        bufferingHints.map(value => value.asEditable),
        retryOptions.map(value => value.asEditable),
        s3BackupMode.map(value => value),
        s3DestinationDescription.map(value => value.asEditable),
        processingConfiguration.map(value => value.asEditable),
        cloudWatchLoggingOptions.map(value => value.asEditable),
        vpcConfigurationDescription.map(value => value.asEditable),
        documentIdOptions.map(value => value.asEditable)
      )
    def roleARN: Optional[RoleARN]
    def domainARN: Optional[ElasticsearchDomainARN]
    def clusterEndpoint: Optional[ElasticsearchClusterEndpoint]
    def indexName: Optional[ElasticsearchIndexName]
    def typeName: Optional[ElasticsearchTypeName]
    def indexRotationPeriod
        : Optional[zio.aws.firehose.model.ElasticsearchIndexRotationPeriod]
    def bufferingHints
        : Optional[zio.aws.firehose.model.ElasticsearchBufferingHints.ReadOnly]
    def retryOptions
        : Optional[zio.aws.firehose.model.ElasticsearchRetryOptions.ReadOnly]
    def s3BackupMode: Optional[zio.aws.firehose.model.ElasticsearchS3BackupMode]
    def s3DestinationDescription
        : Optional[zio.aws.firehose.model.S3DestinationDescription.ReadOnly]
    def processingConfiguration
        : Optional[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly]
    def cloudWatchLoggingOptions
        : Optional[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly]
    def vpcConfigurationDescription
        : Optional[zio.aws.firehose.model.VpcConfigurationDescription.ReadOnly]
    def documentIdOptions
        : Optional[zio.aws.firehose.model.DocumentIdOptions.ReadOnly]
    def getRoleARN: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARN", roleARN)
    def getDomainARN: ZIO[Any, AwsError, ElasticsearchDomainARN] =
      AwsError.unwrapOptionField("domainARN", domainARN)
    def getClusterEndpoint: ZIO[Any, AwsError, ElasticsearchClusterEndpoint] =
      AwsError.unwrapOptionField("clusterEndpoint", clusterEndpoint)
    def getIndexName: ZIO[Any, AwsError, ElasticsearchIndexName] =
      AwsError.unwrapOptionField("indexName", indexName)
    def getTypeName: ZIO[Any, AwsError, ElasticsearchTypeName] =
      AwsError.unwrapOptionField("typeName", typeName)
    def getIndexRotationPeriod: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ElasticsearchIndexRotationPeriod
    ] = AwsError.unwrapOptionField("indexRotationPeriod", indexRotationPeriod)
    def getBufferingHints: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ElasticsearchBufferingHints.ReadOnly
    ] = AwsError.unwrapOptionField("bufferingHints", bufferingHints)
    def getRetryOptions: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ElasticsearchRetryOptions.ReadOnly
    ] = AwsError.unwrapOptionField("retryOptions", retryOptions)
    def getS3BackupMode
        : ZIO[Any, AwsError, zio.aws.firehose.model.ElasticsearchS3BackupMode] =
      AwsError.unwrapOptionField("s3BackupMode", s3BackupMode)
    def getS3DestinationDescription: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.S3DestinationDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "s3DestinationDescription",
      s3DestinationDescription
    )
    def getProcessingConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ProcessingConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "processingConfiguration",
      processingConfiguration
    )
    def getCloudWatchLoggingOptions: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "cloudWatchLoggingOptions",
      cloudWatchLoggingOptions
    )
    def getVpcConfigurationDescription: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.VpcConfigurationDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "vpcConfigurationDescription",
      vpcConfigurationDescription
    )
    def getDocumentIdOptions: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.DocumentIdOptions.ReadOnly
    ] = AwsError.unwrapOptionField("documentIdOptions", documentIdOptions)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
  ) extends zio.aws.firehose.model.ElasticsearchDestinationDescription.ReadOnly {
    override val roleARN: Optional[RoleARN] = zio.aws.core.internal
      .optionalFromNullable(impl.roleARN())
      .map(value => zio.aws.firehose.model.primitives.RoleARN(value))
    override val domainARN: Optional[ElasticsearchDomainARN] =
      zio.aws.core.internal
        .optionalFromNullable(impl.domainARN())
        .map(value =>
          zio.aws.firehose.model.primitives.ElasticsearchDomainARN(value)
        )
    override val clusterEndpoint: Optional[ElasticsearchClusterEndpoint] =
      zio.aws.core.internal
        .optionalFromNullable(impl.clusterEndpoint())
        .map(value =>
          zio.aws.firehose.model.primitives.ElasticsearchClusterEndpoint(value)
        )
    override val indexName: Optional[ElasticsearchIndexName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.indexName())
        .map(value =>
          zio.aws.firehose.model.primitives.ElasticsearchIndexName(value)
        )
    override val typeName: Optional[ElasticsearchTypeName] =
      zio.aws.core.internal
        .optionalFromNullable(impl.typeName())
        .map(value =>
          zio.aws.firehose.model.primitives.ElasticsearchTypeName(value)
        )
    override val indexRotationPeriod
        : Optional[zio.aws.firehose.model.ElasticsearchIndexRotationPeriod] =
      zio.aws.core.internal
        .optionalFromNullable(impl.indexRotationPeriod())
        .map(value =>
          zio.aws.firehose.model.ElasticsearchIndexRotationPeriod.wrap(value)
        )
    override val bufferingHints: Optional[
      zio.aws.firehose.model.ElasticsearchBufferingHints.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.bufferingHints())
      .map(value =>
        zio.aws.firehose.model.ElasticsearchBufferingHints.wrap(value)
      )
    override val retryOptions
        : Optional[zio.aws.firehose.model.ElasticsearchRetryOptions.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.retryOptions())
        .map(value =>
          zio.aws.firehose.model.ElasticsearchRetryOptions.wrap(value)
        )
    override val s3BackupMode
        : Optional[zio.aws.firehose.model.ElasticsearchS3BackupMode] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3BackupMode())
        .map(value =>
          zio.aws.firehose.model.ElasticsearchS3BackupMode.wrap(value)
        )
    override val s3DestinationDescription
        : Optional[zio.aws.firehose.model.S3DestinationDescription.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.s3DestinationDescription())
        .map(value =>
          zio.aws.firehose.model.S3DestinationDescription.wrap(value)
        )
    override val processingConfiguration
        : Optional[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.processingConfiguration())
        .map(value =>
          zio.aws.firehose.model.ProcessingConfiguration.wrap(value)
        )
    override val cloudWatchLoggingOptions
        : Optional[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.cloudWatchLoggingOptions())
        .map(value =>
          zio.aws.firehose.model.CloudWatchLoggingOptions.wrap(value)
        )
    override val vpcConfigurationDescription: Optional[
      zio.aws.firehose.model.VpcConfigurationDescription.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.vpcConfigurationDescription())
      .map(value =>
        zio.aws.firehose.model.VpcConfigurationDescription.wrap(value)
      )
    override val documentIdOptions
        : Optional[zio.aws.firehose.model.DocumentIdOptions.ReadOnly] =
      zio.aws.core.internal
        .optionalFromNullable(impl.documentIdOptions())
        .map(value => zio.aws.firehose.model.DocumentIdOptions.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
  ): zio.aws.firehose.model.ElasticsearchDestinationDescription.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-firehose_3-5.17.104.5-sources.jar: zio/aws/firehose/model/ElasticsearchDestinationDescription.scala <==
package zio.aws.firehose.model
import zio.aws.firehose.model.primitives.{
  ElasticsearchIndexName,
  ElasticsearchTypeName,
  ElasticsearchDomainARN,
  RoleARN,
  ElasticsearchClusterEndpoint
}
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ElasticsearchDestinationDescription(
    roleARN: Option[RoleARN] = None,
    domainARN: Option[ElasticsearchDomainARN] = None,
    clusterEndpoint: Option[ElasticsearchClusterEndpoint] = None,
    indexName: Option[ElasticsearchIndexName] = None,
    typeName: Option[ElasticsearchTypeName] = None,
    indexRotationPeriod: Option[
      zio.aws.firehose.model.ElasticsearchIndexRotationPeriod
    ] = None,
    bufferingHints: Option[zio.aws.firehose.model.ElasticsearchBufferingHints] =
      None,
    retryOptions: Option[zio.aws.firehose.model.ElasticsearchRetryOptions] =
      None,
    s3BackupMode: Option[zio.aws.firehose.model.ElasticsearchS3BackupMode] =
      None,
    s3DestinationDescription: Option[
      zio.aws.firehose.model.S3DestinationDescription
    ] = None,
    processingConfiguration: Option[
      zio.aws.firehose.model.ProcessingConfiguration
    ] = None,
    cloudWatchLoggingOptions: Option[
      zio.aws.firehose.model.CloudWatchLoggingOptions
    ] = None,
    vpcConfigurationDescription: Option[
      zio.aws.firehose.model.VpcConfigurationDescription
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription = {
    import ElasticsearchDestinationDescription.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
      .builder()
      .optionallyWith(
        roleARN.map(value => RoleARN.unwrap(value): java.lang.String)
      )(_.roleARN)
      .optionallyWith(
        domainARN.map(value =>
          ElasticsearchDomainARN.unwrap(value): java.lang.String
        )
      )(_.domainARN)
      .optionallyWith(
        clusterEndpoint.map(value =>
          ElasticsearchClusterEndpoint.unwrap(value): java.lang.String
        )
      )(_.clusterEndpoint)
      .optionallyWith(
        indexName.map(value =>
          ElasticsearchIndexName.unwrap(value): java.lang.String
        )
      )(_.indexName)
      .optionallyWith(
        typeName.map(value =>
          ElasticsearchTypeName.unwrap(value): java.lang.String
        )
      )(_.typeName)
      .optionallyWith(indexRotationPeriod.map(value => value.unwrap))(
        _.indexRotationPeriod
      )
      .optionallyWith(bufferingHints.map(value => value.buildAwsValue()))(
        _.bufferingHints
      )
      .optionallyWith(retryOptions.map(value => value.buildAwsValue()))(
        _.retryOptions
      )
      .optionallyWith(s3BackupMode.map(value => value.unwrap))(_.s3BackupMode)
      .optionallyWith(
        s3DestinationDescription.map(value => value.buildAwsValue())
      )(_.s3DestinationDescription)
      .optionallyWith(
        processingConfiguration.map(value => value.buildAwsValue())
      )(_.processingConfiguration)
      .optionallyWith(
        cloudWatchLoggingOptions.map(value => value.buildAwsValue())
      )(_.cloudWatchLoggingOptions)
      .optionallyWith(
        vpcConfigurationDescription.map(value => value.buildAwsValue())
      )(_.vpcConfigurationDescription)
      .build()
  }
  def asReadOnly
      : zio.aws.firehose.model.ElasticsearchDestinationDescription.ReadOnly =
    zio.aws.firehose.model.ElasticsearchDestinationDescription
      .wrap(buildAwsValue())
}
object ElasticsearchDestinationDescription {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.firehose.model.ElasticsearchDestinationDescription =
      zio.aws.firehose.model.ElasticsearchDestinationDescription(
        roleARN.map(value => value),
        domainARN.map(value => value),
        clusterEndpoint.map(value => value),
        indexName.map(value => value),
        typeName.map(value => value),
        indexRotationPeriod.map(value => value),
        bufferingHints.map(value => value.asEditable),
        retryOptions.map(value => value.asEditable),
        s3BackupMode.map(value => value),
        s3DestinationDescription.map(value => value.asEditable),
        processingConfiguration.map(value => value.asEditable),
        cloudWatchLoggingOptions.map(value => value.asEditable),
        vpcConfigurationDescription.map(value => value.asEditable)
      )
    def roleARN: Option[RoleARN]
    def domainARN: Option[ElasticsearchDomainARN]
    def clusterEndpoint: Option[ElasticsearchClusterEndpoint]
    def indexName: Option[ElasticsearchIndexName]
    def typeName: Option[ElasticsearchTypeName]
    def indexRotationPeriod
        : Option[zio.aws.firehose.model.ElasticsearchIndexRotationPeriod]
    def bufferingHints
        : Option[zio.aws.firehose.model.ElasticsearchBufferingHints.ReadOnly]
    def retryOptions
        : Option[zio.aws.firehose.model.ElasticsearchRetryOptions.ReadOnly]
    def s3BackupMode: Option[zio.aws.firehose.model.ElasticsearchS3BackupMode]
    def s3DestinationDescription
        : Option[zio.aws.firehose.model.S3DestinationDescription.ReadOnly]
    def processingConfiguration
        : Option[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly]
    def cloudWatchLoggingOptions
        : Option[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly]
    def vpcConfigurationDescription
        : Option[zio.aws.firehose.model.VpcConfigurationDescription.ReadOnly]
    def getRoleARN: ZIO[Any, AwsError, RoleARN] =
      AwsError.unwrapOptionField("roleARN", roleARN)
    def getDomainARN: ZIO[Any, AwsError, ElasticsearchDomainARN] =
      AwsError.unwrapOptionField("domainARN", domainARN)
    def getClusterEndpoint: ZIO[Any, AwsError, ElasticsearchClusterEndpoint] =
      AwsError.unwrapOptionField("clusterEndpoint", clusterEndpoint)
    def getIndexName: ZIO[Any, AwsError, ElasticsearchIndexName] =
      AwsError.unwrapOptionField("indexName", indexName)
    def getTypeName: ZIO[Any, AwsError, ElasticsearchTypeName] =
      AwsError.unwrapOptionField("typeName", typeName)
    def getIndexRotationPeriod: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ElasticsearchIndexRotationPeriod
    ] = AwsError.unwrapOptionField("indexRotationPeriod", indexRotationPeriod)
    def getBufferingHints: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ElasticsearchBufferingHints.ReadOnly
    ] = AwsError.unwrapOptionField("bufferingHints", bufferingHints)
    def getRetryOptions: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ElasticsearchRetryOptions.ReadOnly
    ] = AwsError.unwrapOptionField("retryOptions", retryOptions)
    def getS3BackupMode
        : ZIO[Any, AwsError, zio.aws.firehose.model.ElasticsearchS3BackupMode] =
      AwsError.unwrapOptionField("s3BackupMode", s3BackupMode)
    def getS3DestinationDescription: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.S3DestinationDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "s3DestinationDescription",
      s3DestinationDescription
    )
    def getProcessingConfiguration: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.ProcessingConfiguration.ReadOnly
    ] = AwsError.unwrapOptionField(
      "processingConfiguration",
      processingConfiguration
    )
    def getCloudWatchLoggingOptions: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly
    ] = AwsError.unwrapOptionField(
      "cloudWatchLoggingOptions",
      cloudWatchLoggingOptions
    )
    def getVpcConfigurationDescription: ZIO[
      Any,
      AwsError,
      zio.aws.firehose.model.VpcConfigurationDescription.ReadOnly
    ] = AwsError.unwrapOptionField(
      "vpcConfigurationDescription",
      vpcConfigurationDescription
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
  ) extends zio.aws.firehose.model.ElasticsearchDestinationDescription.ReadOnly {
    override val roleARN: Option[RoleARN] = scala
      .Option(impl.roleARN())
      .map(value => zio.aws.firehose.model.primitives.RoleARN(value))
    override val domainARN: Option[ElasticsearchDomainARN] = scala
      .Option(impl.domainARN())
      .map(value =>
        zio.aws.firehose.model.primitives.ElasticsearchDomainARN(value)
      )
    override val clusterEndpoint: Option[ElasticsearchClusterEndpoint] = scala
      .Option(impl.clusterEndpoint())
      .map(value =>
        zio.aws.firehose.model.primitives.ElasticsearchClusterEndpoint(value)
      )
    override val indexName: Option[ElasticsearchIndexName] = scala
      .Option(impl.indexName())
      .map(value =>
        zio.aws.firehose.model.primitives.ElasticsearchIndexName(value)
      )
    override val typeName: Option[ElasticsearchTypeName] = scala
      .Option(impl.typeName())
      .map(value =>
        zio.aws.firehose.model.primitives.ElasticsearchTypeName(value)
      )
    override val indexRotationPeriod
        : Option[zio.aws.firehose.model.ElasticsearchIndexRotationPeriod] =
      scala
        .Option(impl.indexRotationPeriod())
        .map(value =>
          zio.aws.firehose.model.ElasticsearchIndexRotationPeriod.wrap(value)
        )
    override val bufferingHints
        : Option[zio.aws.firehose.model.ElasticsearchBufferingHints.ReadOnly] =
      scala
        .Option(impl.bufferingHints())
        .map(value =>
          zio.aws.firehose.model.ElasticsearchBufferingHints.wrap(value)
        )
    override val retryOptions
        : Option[zio.aws.firehose.model.ElasticsearchRetryOptions.ReadOnly] =
      scala
        .Option(impl.retryOptions())
        .map(value =>
          zio.aws.firehose.model.ElasticsearchRetryOptions.wrap(value)
        )
    override val s3BackupMode
        : Option[zio.aws.firehose.model.ElasticsearchS3BackupMode] = scala
      .Option(impl.s3BackupMode())
      .map(value =>
        zio.aws.firehose.model.ElasticsearchS3BackupMode.wrap(value)
      )
    override val s3DestinationDescription
        : Option[zio.aws.firehose.model.S3DestinationDescription.ReadOnly] =
      scala
        .Option(impl.s3DestinationDescription())
        .map(value =>
          zio.aws.firehose.model.S3DestinationDescription.wrap(value)
        )
    override val processingConfiguration
        : Option[zio.aws.firehose.model.ProcessingConfiguration.ReadOnly] =
      scala
        .Option(impl.processingConfiguration())
        .map(value =>
          zio.aws.firehose.model.ProcessingConfiguration.wrap(value)
        )
    override val cloudWatchLoggingOptions
        : Option[zio.aws.firehose.model.CloudWatchLoggingOptions.ReadOnly] =
      scala
        .Option(impl.cloudWatchLoggingOptions())
        .map(value =>
          zio.aws.firehose.model.CloudWatchLoggingOptions.wrap(value)
        )
    override val vpcConfigurationDescription
        : Option[zio.aws.firehose.model.VpcConfigurationDescription.ReadOnly] =
      scala
        .Option(impl.vpcConfigurationDescription())
        .map(value =>
          zio.aws.firehose.model.VpcConfigurationDescription.wrap(value)
        )
  }
  def wrap(
      impl: software.amazon.awssdk.services.firehose.model.ElasticsearchDestinationDescription
  ): zio.aws.firehose.model.ElasticsearchDestinationDescription.ReadOnly =
    new Wrapper(impl)
}
